// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/*===================================================================*/ 
/*-------------------------------------------------------------------   
   epic_defs.h 

   Version| Date    | Comments                             
   ------------------------------------------------------------------
   0.0    | 19/06/95| Creation
   0.1    | 26/03/96| actualisation des HBR_xxx 
   0.2    | 23/04/96| Test image: 900->800
   0.3    | 13/06/96| Testim, inverson DX DY retablie      
   0.4    | 26/06/96| Modes

   Aim : EPIC fixed parameters are gathered here.
  
   Note: The parameters relevant to GSE software or hardware
         must not be here. 
         
  -------------------------------------------------------------------*/ 
/*===================================================================*/ 

/*== OFFSET TABLES and CCD NODES ==*/
#define NOFF 8  /* Number of offset table */

#define OFFSIZE 1024
typedef u_short OFFSET[ OFFSIZE ] ;

typedef struct {
	             u_short rms     ;
	             OFFSET  OffsetX ;
	             OFFSET  OffsetY ;	             
	           } NODE_INFO[ NOFF ]  ;


/*== Image de test ==*/
#define TESTIM_DX 40
#define TESTIM_DY 20
typedef u_short TESTIM[ TESTIM_DY ][ TESTIM_DX ] ;
#define TESTIMSIZE 800

/*== CCD size ==*/
#define AE_CCD_X 610
#define AE_CCD_Y 602

#define AE_GROUPSEQNBR 4

/* Sequencer programme lenght */
#define AE_PRGLEN 512
/* Sequencer direct addressing area lenght */
#define AE_DIRADDLEN 254

/*== EDU ==*/
#define EDU_NBR 8

#define EDU_NSID  5
#define EDU_NPIX 25
#define EDU_NPAT 32
#define EDU_NPAT3_3 256 
#define EDU_NPATMASK 100 

/* EDU MODE ( 2 bits ) */
typedef enum { EDU_TRA, EDU_TIM, EDU_THR, EDU_IMA } EDU_MODE ;


/* EDU OUTPUT FORMAT HBR-CD */        
#define HBR_MASK    0xE000

#define HBR_HEADER  0xC000 
#define HBR_TRAILER 0xE000 
#define HBR_TIME    0x8000 
#define HBR_DATA    0xA000  /* whatever the mode */

/* In HBR-CD TRANSPARENT */
#define HBR_EOL 0x1000

/* SYNCHRO BITS in SDD */
/*   d15  d14  d13  d12  d11----------d00
**   eoi  eof  eol  inv       data 
*/
#define SE_EOI 0x8000
#define SE_EOF 0x4000
#define SE_EOL 0x2000
#define SE_INV 0x1000


/* CCD VOLTAGES */

#define AE_NVOLT 16
typedef struct {
    u_char Addr ;
	u_char Data ;
	           } EMAE_CCD1_VOLTAGES[ AE_NVOLT ] ;
	           
	          
